@@ -2,7 +2,7 @@
 """
 Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
 Edition) available.
-Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
+Copyright (C) 2017 THL A29 Limited, a Tencent company. All rights reserved.
 Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://opensource.org/licenses/MIT
@@ -94,3 +94,15 @@ class RewritableNodeOutput(Var):
         base = super(RewritableNodeOutput, self).to_dict()
         base["source_act"] = self.source_act
         return base
+
+
+class InitializedRewritableNodeOutput(Var):
+    def __init__(self, source_act, *args, **kwargs):
+        self.source_act = source_act
+        super(InitializedRewritableNodeOutput, self).__init__(*args, **kwargs)
+
+    def to_dict(self):
+        base = super(InitializedRewritableNodeOutput, self).to_dict()
+        base["source_act"] = self.source_act
+        base["need_initialization"] = True
+        return base
